@@ -19,7 +19,7 @@ except ImportError:
     from cgi import parse_qsl
 
 
-__version__ = '0.2.4'
+__version__ = '0.3'
 BACKENDS = {
     'postgresql': 'django.db.backends.postgresql_psycopg2',
     'mysql': 'django.db.backends.mysql',
@@ -216,7 +216,8 @@ def main(argv):
 
     urlpatterns = make_urlpatterns(options.apps)
     if options.admin:
-        urlpatterns += make_admin_urlpatterns()
+        # Force /admin/ first in the patterns.
+        urlpatterns = make_admin_urlpatterns() + urlpatterns
 
     configure_urlconf(urlpatterns)
     execute_from_command_line(['django-mini'] + arguments)
@@ -225,10 +226,6 @@ def main(argv):
 def configure_urlconf(patterns):
     """Sets up Django's settings.ROOT_URLCONF patterns."""
     from django.conf import settings
-    from django.core.exceptions import ImproperlyConfigured
-
-    if not patterns:
-        raise ImproperlyConfigured('--app or --admin is required.')
 
     # Has to be hashable or a string naming a module.
     settings.ROOT_URLCONF = tuple(patterns)
